@@ -1,17 +1,14 @@
 import re
 import string
-import subprocess
 
-import yaml
-import pandas
 from rapidfuzz import fuzz, process
 from sqlalchemy.orm.exc import NoResultFound, MultipleResultsFound
 
-from menustat.log import *
+from menustat.log import logger, wrap, writelog
 from menustat.utils import *
 # add_meta, loop_string_replace, return_range,
-from menustat.orm import Base, MenuItem, AnnualItemData, return_largest_id_plusone
-from menustat.settings import YEAR, ANALYST, engine, session, config
+from menustat.orm import MenuItem, AnnualItemData, return_largest_id_plusone
+from menustat.settings import YEAR, ANALYST, session, config
 
 
 class CollectedDf():
@@ -56,8 +53,8 @@ class CollectedDf():
                     AnnualItemData.carbohydrates).\
                 join(MenuItem).\
                 filter(MenuItem.franchise_id == self.f_id)
-        logger.debug("{}".format(self.__dict__))
-        logger.info("# items: {}".format(self.all_annual_items.count()))
+        logger.debug("%s", self.__dict__)
+        logger.info("# items: %s", self.all_annual_items.count())
 
 
     @wrap(writelog, writelog)
@@ -69,8 +66,9 @@ class CollectedDf():
         if len(self.nutr_df[self.nutr_df["serving_size"] == '']) > 10:
             self.nutr_df["serving_size"] = self.nutr_df["item_name"].\
                 apply(lambda x: self.name_to_serving(str(x)))
-        logger.debug("autogenerate_description BEGIN:\n{}".format(self.nutr_df.head()))
-        self.nutr_df['item_description'] = self.nutr_df.apply(lambda r: self.autogenerate_description(r), axis=1)
+        logger.debug("autogenerate_description BEGIN:\n%s", self.nutr_df.head())
+        self.nutr_df['item_description'] = self.nutr_df.apply(
+                            lambda r: self.autogenerate_description(r), axis=1)
 
         self.nutr_df['item_name'] = self.nutr_df['item_name'].str.strip()
         self.combine_duplicate_rows()
@@ -79,7 +77,7 @@ class CollectedDf():
         self.standardize_df_contents()
         self.nutr_df['menu_item_id'] = self.nutr_df.apply(lambda x: self.\
                 pair_with_menu_ids(x), axis=1)
-        logger.debug("Clean: item_description end:\n{}".format(self.nutr_df.item_description))
+        logger.debug("Clean: item_description end:\n%s", self.nutr_df.item_description)
         check_df_for_issues(self.name, self.nutr_df)
 
 
@@ -89,13 +87,13 @@ class CollectedDf():
         1. Search db for AID entry using year, f_id, aid_row.item_name. If
         item found, return AID id and mi_id. If multiple items
         returned, flag issue.
-        2. If no items returned, run self.return_MenuItem() to find correct
+        2. If no items returned, run self.return_menuitem() to find correct
         menu_item and return mi_id of returned menu_item.
         """
 
         if aid_row.item_name == "":
             logger.warning("empty item_name string detected - ending "
-                "return_MenuItem method")
+                "return_menuitem method")
             return
         aid_query = session.query(AnnualItemData).\
         join(MenuItem).\
@@ -106,36 +104,40 @@ class CollectedDf():
             matched_db_entry = aid_query.one()
         except MultipleResultsFound:
             logger.warning("WARNING: multiple matches for annual_item_"
-            "data search:{}\nreturned items:".format(row['item_name']))
+            "data search:%s\nreturned items:", aid_row['item_name'])
             matched_db_entries = aid_query.all()
             for e in matched_db_entries:
-                logger.info("item:{} cals:{} carbs:{} add_date:{}".format(\
-                e.item_name, e.calories, e.carbohydrates, e.created_at))
+                logger.info("item:%s cals:%s carbs:%s add_date:%s",
+                        e.item_name, e.calories, e.carbohydrates, e.created_at)
             mi_id = ",".join([e.id for e in matched_db_entries])
         except NoResultFound:
             logger.info("No AnnualItemData entry found.")
-            mi_id = self.return_MenuItem(aid_row)
+            mi_id = self.return_menuitem(aid_row)
         else:
-            mi_id = str(matched_db_entry.menu_item_id)
+            # had changed this to a string for some reason, which caused problems down the line
+            # mi_id = str(matched_db_entry.menu_item_id)
+            mi_id = matched_db_entry.menu_item_id
         return mi_id
 
 
     @wrap(writelog, writelog)
     def remove_unneeded_cols(self):
-        standard_cols = ["item_name","menu_item_id","item_description",\
-            "serving_size_household", "serving_size","serving_size_unit",
+        """If a column name is not in the list of required columns, delete it.
+        """
+        standard_cols = ["menu_item_id", "item_name", "item_description",
+            "serving_size", "serving_size_unit", "serving_size_household",
             "notes", "iurl"]
         standard_cols.extend(self.nutr_columns)
-        logger.info("cols:{}".format(self.nutr_df.columns))
+        logger.info("cols:%s", self.nutr_df.columns)
         not_in_df = [c for c in standard_cols if c not in self.nutr_df]
-        logger.info("not_in_df:{}".format(not_in_df))
+        logger.info("not_in_df:%s", not_in_df)
         for col in not_in_df:
             self.nutr_df[col] = ""
         self.nutr_df = self.nutr_df[standard_cols]
 
 
     def return_range_search_list(self, aid_item):
-        logger.debug("return_range_search_list: {}".format(aid_item))
+        logger.debug("return_range_search_list: %s", aid_item)
         ranges = {}
         for item in ["calories", "protein", "total_fat", "carbohydrates"]:
             val = getattr(aid_item, item, None)
@@ -144,7 +146,7 @@ class CollectedDf():
                     ranges[item] = return_range(val)
                 except TypeError:
                     pass
-        logger.debug("return_range_search_list ranges: {}".format(ranges))
+        logger.debug("return_range_search_list ranges: %s",ranges)
         return ranges
 
 
@@ -156,19 +158,20 @@ class CollectedDf():
             fuzzy match on name.
         3. If either match succeeds, return menu_item_id of AID match.
         """
-        logger.debug("START: {}".format(row))
-        returned_items = self.all_annual_items.filter(AnnualItemData.year < YEAR)
+        logger.debug("START: %s", row)
         try:
+            returned_items = self.all_annual_items.filter(AnnualItemData.year < YEAR)
             returned_items = self.all_annual_items.\
                 filter(AnnualItemData.calories == row.calories).\
                 filter(AnnualItemData.protein == row.protein).\
                 filter(AnnualItemData.total_fat == row.total_fat).\
                 filter(AnnualItemData.carbohydrates == row.carbohydrates)
-            logger.debug("returned_items1 query: {}".format(returned_items))
+            logger.debug("returned_items1 query: %s", returned_items)
             if returned_items.count() == 0:
                 raise ValueError('No returned_items for exact match')
         except Exception as e:
-            logger.debug("{}; trying range match".format(e))
+            returned_items = self.all_annual_items.filter(AnnualItemData.year < YEAR)
+            logger.debug("%s; trying range match", e)
             # need light conditional for these - use if range exists, don't if not.
             range_dict = self.return_range_search_list(row)
 
@@ -176,36 +179,37 @@ class CollectedDf():
             for k, v in range_search_dict.items():
                 returned_items = returned_items.filter(k > v[0]).\
                         filter(k < v[1])
-            logger.debug("returned_items query: {}".format(returned_items))
+            logger.debug("returned_items query: %s", returned_items)
 
-        logger.info("returned_items #: {}".format(returned_items.count()))
+        logger.info("returned_items #: %s", returned_items.count())
         if returned_items.count() == 1:
             aid_item = returned_items.one()
             plain_ratio = fuzz.ratio(row.item_name, aid_item.item_name)
             token_ratio = fuzz.token_set_ratio(row.item_name, aid_item.item_name)
-            partial_ratio = fuzz.token_set_ratio(row.item_name, aid_item.item_name)
             if plain_ratio > 75 or token_ratio > 75:
                 menu_item_id = aid_item.menu_item_id
-                logger.debug("returned result:{}, {}, ratio={}, token_set_ratio={}".format(row.item_name, aid_item.item_name, plain_ratio, token_ratio))
+                logger.debug("returned result: %s, %s, ratio=%s, token_set_ratio=%s",
+                        row.item_name, aid_item.item_name, plain_ratio, token_ratio)
             else:
-                logger.debug("single result didn't pass 75%:{}, {}, ratio={}, token_set_ratio={}".format(row.item_name, aid_item.item_name, plain_ratio, token_ratio))
+                logger.debug("single result didn't pass 75 percent - %s, %s, ratio=%s, token_set_ratio=%s",
+                        row.item_name, aid_item.item_name, plain_ratio, token_ratio)
                 menu_item_id = None
         elif returned_items.count() > 1:
             logger.info("too many returned items!")
             for item in returned_items.all():
-                logger.info("{}, {}".format(item.id, item.item_name))
+                logger.info("%s, %s", item.id, item.item_name)
                 item.menu_item_id = self.return_closest_match(item)
         elif returned_items.count() == 0:
             logger.info("no returned items!")
             menu_item_id = None
-        logger.debug("END menu_item_id:{}".format(menu_item_id))
+        logger.debug("END menu_item_id:%s", menu_item_id)
         return menu_item_id
 
 
     def clean_item_name(self, name):
         """Remove unneeded data from item name and restructure serving data.
         """
-        logger.debug("preclean: {}".format(name))
+        logger.debug("preclean: %s", name)
         name = loop_string_replace(self.cleaner['nd_cleaner'], name, regex=False)
         name = loop_string_replace(self.cleaner['nd_cleaner_re'], name)
         count_re = re.search(r'\((\d+)\)$', name)
@@ -217,7 +221,7 @@ class CollectedDf():
             name = "{}, {}".format(name, str(count_counter_re.group(1)))
             name = name.replace(str(count_counter_re.group(0)), "")
         name = name.strip("+ ")
-        logger.debug("cleaned: {}".format(name))
+        logger.debug("cleaned: %s", name)
         return name
 
 
@@ -245,7 +249,7 @@ class CollectedDf():
         """
         colnames = ['item_name']
         colnames.extend(self.nutr_columns)
-        logger.debug("platonic colnames: {}".format(colnames))
+        logger.debug("platonic colnames: %s",colnames)
         dupecheck = self.nutr_df[self.nutr_df.duplicated(subset=colnames,
                                             keep=False)].fillna("")
         if not dupecheck.empty:
@@ -276,11 +280,9 @@ class CollectedDf():
             if not, create new MenuItem entry.
         6. Insert new AnnualItemData objects into database.
         """
-        new_id = return_largest_id_plusone(AnnualItemData, session)
-        aid_objects = self.nutr_df.apply(lambda x: self.\
-                produce_aid_object(x), axis=1)
+        aid_objects = self.nutr_df.apply(lambda x: self.produce_aid_object(x), axis=1)
         new_db_entries = aid_objects.tolist()
-        if dryrun == True:
+        if dryrun:
             pass
         else:
             session.add_all(new_db_entries)
@@ -290,13 +292,13 @@ class CollectedDf():
     def produce_aid_object(self, row):
         aid_args = {k:v for k, v in row.to_dict().items() if k != "iurl"}
         annual_item = AnnualItemData(**aid_args)
-        annual_item = add_meta(annual_item, created=False)
-        # annual_item.updated_by = ANALYST
-        # annual_item.updated_at = dt.datetime.now()
+        # annual_item = add_meta(annual_item, created=False)
+        annual_item.updated_by = ANALYST
+        annual_item.updated_at = dt.datetime.now()
         return annual_item
 
 
-    def return_MenuItem(self, annual_item):
+    def return_menuitem(self, annual_item):
         """ Return MenuItem match for AnnualItemData object.
         1. Attempt direct match using item name.
         2. If direct match returns multiple results, return closest match.
@@ -307,36 +309,37 @@ class CollectedDf():
             Menu_Item object and insert it into the database.
         """
         item_name = f"{annual_item.item_name}"
-        logger.info(f"namesearch: {item_name}")
+        logger.info("namesearch: %s", item_name)
         menu_item_query = session.query(MenuItem.id).\
                 filter(MenuItem.item_name.ilike(f'{item_name}')).\
                 filter(MenuItem.franchise_id == self.f_id)
         try:
             menu_item_id = menu_item_query.one()[0]
-            logger.info(f"MenuItem match: {item_name}")
+            logger.info("MenuItem match: %s", item_name)
         except MultipleResultsFound:
-            logger.info(f"ISSUE: multiple matches for: {annual_item.__dict__}")
+            logger.info("ISSUE: multiple matches for: %s", annual_item.__dict__)
             menu_item_id = self.fuzzy_match_menu_item(annual_item)
         except NoResultFound:
-            logger.info(f"No exact match: {item_name}\nTrying match_by_nutrition")
+            logger.info("No exact match: %s\nTrying match_by_nutrition", item_name)
             try:
                 menu_item_id = self.match_by_nutrition(annual_item)
                 if menu_item_id is None:
                     raise TypeError("no match found")
             except Exception as e:
-                logger.info("match_by_nutrition fail\n{}".format(e))
+                logger.info("match_by_nutrition fail\n%s", e)
                 try:
                     logger.info("trying name-only fuzzy match")
                     menu_item_id = self.fuzzy_match_menu_item(annual_item)
                 except TypeError as e:
-                    logger.info("fuzzy match failed: {}".format(e))
+                    logger.info("fuzzy match failed: %s", e)
                     menu_item_id = None
                 except Exception as e:
-                    logger.info(f"fuzzy match failed: {e}", exc_info=True)
-                    logger.info("adding new Menu_Item entry")
-                    menu_item_id = self.add_new_menuitem(annual_item)
+                    logger.info("fuzzy match failed: %s", e, exc_info=True)
+                    # logger.info("adding new Menu_Item entry")
+                    # menu_item_id = self.add_new_menuitem(annual_item)
+                    menu_item_id = None
 
-        logger.info("menu_item_id:{}".format(menu_item_id))
+        logger.info("menu_item_id:%s", menu_item_id)
         return menu_item_id
 
 
@@ -346,7 +349,7 @@ class CollectedDf():
         2. Return item_name values that match self.item_name at ≥ 91%
         3. Select first entry.
         """
-        logger.info("fuzzy_match: {}".format(annual_item.item_name))
+        logger.info("fuzzy_match: %s", annual_item.item_name)
         # plain_ratio = fuzz.ratio(self.item_name, aid_item.item_name)
         # token_ratio = fuzz.token_set_ratio(self.item_name, aid_item.item_name)
         # partial_ratio = fuzz.token_set_ratio(self.item_name, aid_item.item_name)
@@ -354,26 +357,25 @@ class CollectedDf():
         returned = process.extractOne(annual_item.item_name,\
                 all_franchise_item_names, score_cutoff=match_pct)
         if not returned:
-            desc = f"{annual_item.item_name} {annual_item.item_description}"
             returned = process.extractOne(annual_item.item_description,\
                     all_franchise_item_names, score_cutoff=match_pct)
-        logger.info("returned pair: {}::{}".format(annual_item.item_name,\
-                returned))
+        logger.info("returned pair: %s::%s", annual_item.item_name, returned)
         returned_id = [i[0] for i in self.all_menu_items if i[1] ==\
                 returned[0]]
-        menu_item_id = None if not returned_id else str(returned_id[0])
-        logger.info("menu_item_id: {}".format(menu_item_id))
+        # why is this stringed here? replace with non-stringed
+        # menu_item_id = None if not returned_id else str(returned_id[0])
+        menu_item_id = None if not returned_id else returned_id[0]
+        logger.info("menu_item_id: %s", menu_item_id)
         return menu_item_id
 
 
     def add_new_menuitem(self, annual_item):
-        logger.debug("START {}".format(annual_item))
+        logger.debug("START %s", annual_item)
         new_menu_items = []
         try:
             new_mi_id = return_largest_id_plusone(MenuItem, session)
-            new_mi_id += 1
         except Exception as e:
-            logger.info("method failed:\n{}".format(e), exc_info=True)
+            logger.info("method failed:\n%s",e, exc_info=True)
         else:
             meta = add_meta({}, created=True)
             new_entry = MenuItem(
@@ -391,17 +393,47 @@ class CollectedDf():
         1. if "description" exists, add  ", " + "menu_section"
         2. if not, "description" = "item_name" + ", " + "menu_section"
         """
-        desc_base = row.item_description if row.item_description != "" else\
-                row.item_name
-        desc = "{}, {}".format(desc_base, row["menu_section"]).\
-                replace(", nan", "")
-        logger.debug("item_description:{}".format(desc))
+        desc_base = row.item_description if row.item_description != "" else row.item_name
+        if "menu_section" in row:
+            desc = "{}, {}".format(desc_base, row["menu_section"]).replace(", nan", "")
+        else:
+            desc = desc_base.replace(", nan", "")
+        logger.debug("item_description:%s", desc)
         desc = re.sub(self.cleaner['remove_from_desc'], "", desc, flags=re.IGNORECASE)
         desc = loop_string_replace(self.cleaner['nd_cleaner'], desc, regex=False)
         desc = loop_string_replace(self.cleaner['nd_cleaner_re'], desc)
 
         return desc
 
+    def clean_serving_size(self):
+        df = self.nutr_df
+        # # if serving_size is already clean, end function.
+        # if df['serving_size'].dtypes in [int64]:
+        #     return
+        #
+        df.loc[df['serving_size'].notnull(), 'serving_size'] = df['serving_size'].astype(str)
+        df = df.replace("^-$", "", regex=True)
+        df['serving_size'] = df['serving_size'].str.strip()
+        df.loc[df['serving_size'].str.contains(self.cleaner["ss_text"], \
+                regex=True), "serving_size_text"] = df['serving_size']
+
+        ssu_re = r"\d+\s*({})".format("|".join(u for u in self.cleaner["serving_units"]))
+        df.loc[df['serving_size'].str.contains(ssu_re, regex=True),\
+                "serving_size_unit"] = df['serving_size']
+
+        df.loc[(df['item_name'].str.contains(self.cleaner["serving_in_name"\
+            ][0], regex=True)) & (df['item_name'].str.contains("(small|medium|large)",
+            regex=True, flags=re.IGNORECASE)), "item_name"
+            ] = df['item_name'].str.replace(self.cleaner['serving_in_name'][0], "", regex=True)
+
+        df.loc[df['serving_size'].str.contains(self.cleaner["ss_house"\
+        ],regex=True), "serving_size_household"] = df['serving_size']
+        df['serving_size_unit'] = df['serving_size_unit'].str.\
+            replace(r"([1234567890\.\/])+", "", regex=True).str.strip()
+        df['serving_size'] = df['serving_size'].str.\
+                    replace(r"([^1234567890\.\/])+", "", regex=True)
+        self.nutr_df = df
+
 
     @wrap(writelog, writelog)
     def standardize_df_contents(self):
@@ -411,34 +443,15 @@ class CollectedDf():
         3. separate serving size value into numeric amount and measure. If
             measure isn't a standard measure, assign to "household"
         """
-        df = self.nutr_df
         # column contents to address: '4130/7140','43 g',"<1","-"
-        df.drop_duplicates(inplace=True)
-        df.fillna("", inplace=True)
-        df.loc[df['serving_size'].notnull(), 'serving_size'] = df['serving_size'].astype(str)
-        df = df.replace("^-$", "", regex=True)
-        df['serving_size'] = df['serving_size'].str.strip()
-
-        df.loc[df['serving_size'].str.contains(self.cleaner["ss_text"], \
-                regex=True), "serving_size_text"] = df['serving_size']
-
-        ssu_re = "\d+\s*({})".format("|".join(u for u in self.cleaner["serving_units"]))
-        df.loc[df['serving_size'].str.contains(ssu_re, regex=True),\
-                "serving_size_unit"] = df['serving_size']
-
-        df.loc[(df['item_name'].str.contains(self.cleaner["serving_in_name"\
-            ][0], regex=True)) & (df['item_name'].str.contains("(small|medium"
-            "|large)", regex=True, flags=re.IGNORECASE)), "item_name"] = df['item_name'].str.replace(self.cleaner['serving_in_name'][0], "", regex=True)
-
-        df.loc[df['serving_size'].str.contains(self.cleaner["ss_house"\
-        ],regex=True), "serving_size_household"] = df['serving_size']
-        df['serving_size_unit'] = df['serving_size_unit'].str.\
-            replace(r"([1234567890\.\/])+", "", regex=True).str.strip()
-        df['serving_size'] = df['serving_size'].str.\
-        replace(r"([^1234567890\.\/])+", "", regex=True)
+        self.nutr_df.drop_duplicates(inplace=True)
+        self.nutr_df.fillna("", inplace=True)
+        self.clean_serving_size()
+        df = self.nutr_df
         isnum = r"^\d+([\.\/]\d{1,3})?$"
         for col in self.nutr_columns:
-            logger.debug(f"colname:{col}\ndata overview:\n{df[col]}")
+            logger.debug("colname:%s\ndata overview:\n%s", col, df[col])
+            # first, fix any formatting errors
             df[col] = df[col].astype(str).apply(lambda x: re.sub(r'(\d+),(\d+)', r'\1\2', x))
             text_col = col + "_text"
             df[text_col] = None
@@ -449,7 +462,9 @@ class CollectedDf():
             df.loc[~is_num, col] = ""
             df.loc[is_num, col] = df[text_col]
             df.loc[is_num, text_col] = ""
-            is_perc = df[text_col].str.contains("%", regex=False)
+            lessthan = df[text_col].str.contains("less than ", regex=False)
+            if not df.loc[lessthan].empty:
+                df.loc[lessthan, text_col] = df[text_col].str.replace("less than ", "<")
             deformatted_field = col.replace("_", " ")
             df[col] = df[col].str.replace("{}".format(deformatted_field),\
                 "", regex=True, flags=re.IGNORECASE)
@@ -496,4 +511,4 @@ def check_df_for_issues(name, df):
             issue_list.append(issue)
     if issue_list:
         issues = '\n'.join('{}' for _ in range(len(issue_list))).format(*issue_list)
-        logger.warning(f"ISSUES FOUND FOR {name}\nissues:\n{issues}")
+        logger.warning("ISSUES FOUND FOR %s\nissues:\n%s", name, issues)
